pub struct ObjectSourceMessage {
pub source: i32,
pub source_info: Option<String>,
}Fields
source: i32source_info: Option<String>Implementations
Sourceimpl ObjectSourceMessage
impl ObjectSourceMessage
Sourcepub fn source(&self) -> ObjectSource
pub fn source(&self) -> ObjectSource
Returns the enum value of source, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source(&mut self, value: ObjectSource)
pub fn set_source(&mut self, value: ObjectSource)
Sets source to the provided enum value.
Sourcepub fn source_info(&self) -> &str
pub fn source_info(&self) -> &str
Returns the value of source_info, or the default value if source_info is unset.