pub enum NodeType {
ConstTensorNode(ConstTensorNode),
ImageResizeNode(ImageResizeNode),
ImagePatchesNode(ImagePatchesNode),
VirtualCameraNode(VirtualCameraNode),
ImageClassificationNode(ImageClassificationNode),
ImageObjectDetectionNode(ImageObjectDetectionNode),
ImageOcrNode(ImageOcrNode),
BoundingBoxFilterNode(BoundingBoxFilterNode),
ImageSegmentationNode(ImageSegmentationNode),
ImageInstanceSegmentationNode(ImageInstanceSegmentationNode),
ImageAnomalyDetectionNode(ImageAnomalyDetectionNode),
}Variants
ConstTensorNode(ConstTensorNode)
ImageResizeNode(ImageResizeNode)
ImagePatchesNode(ImagePatchesNode)
VirtualCameraNode(VirtualCameraNode)
ImageClassificationNode(ImageClassificationNode)
ImageObjectDetectionNode(ImageObjectDetectionNode)
ImageOcrNode(ImageOcrNode)
BoundingBoxFilterNode(BoundingBoxFilterNode)
ImageSegmentationNode(ImageSegmentationNode)
ImageInstanceSegmentationNode(ImageInstanceSegmentationNode)
ImageAnomalyDetectionNode(ImageAnomalyDetectionNode)
Implementations
Sourceimpl NodeType
impl NodeType
Sourcepub fn merge(
field: &mut Option<NodeType>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<NodeType>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.